@@ -130,18 +130,18 @@ if (!array_key_exists($page, $allowed_pages)) {
                     <a href="./filemanager/" target="_blank" class="list-group-item list-group-item-action py-3">
                         <i class="fa fa-file me-3"></i>File Manager
                     </a>
-                    <a href="./phpmyadmin-sso.php" target="_blank" class="list-group-item list-group-item-action py-3">
-                        <i class="fa fa-database me-3"></i>phpMyAdmin
-                    </a>
-                    <a href="./pgadmin-sso.php" target="_blank" class="list-group-item list-group-item-action py-3">
-                        <i class="fa fa-database me-3 text-success"></i>pgAdmin 4
-                    </a>
                     <a href="index.php?page=database-management" class="list-group-item list-group-item-action py-3 <?php echo $page === 'database-management' ? 'active' : ''; ?>">
                         <i class="fa fa-database me-3"></i>MySQL Management
                     </a>
+                    <a href="./phpmyadmin-sso.php" target="_blank" class="list-group-item list-group-item-action py-3">
+                        <i class="fa fa-database me-3"></i>phpMyAdmin
+                    </a>
                     <a href="index.php?page=postgresql-management" class="list-group-item list-group-item-action py-3 <?php echo $page === 'postgresql-management' ? 'active' : ''; ?>">
                         <i class="fa fa-database me-3"></i>PostgreSQL Management
                     </a>
+                    <a href="./adminer-sso.php" target="_blank" class="list-group-item list-group-item-action py-3">
+                        <i class="fa fa-database me-3"></i>Adminer
+                    </a>
                     <a href="index.php?page=email-management" class="list-group-item list-group-item-action py-3 <?php echo $page === 'email-management' ? 'active' : ''; ?>">
                         <i class="fa fa-envelope me-3"></i>Email Management
                     </a>
